import { postProtected, getProtected } from './utils';

/**
 * Get a list of all bonuses (pending, active, expired, cleared)
 * @param {string} playerSessionID 
 */
export var getBonuses = function getBonuses(playerSessionID) {
  return getProtected('/bonus', playerSessionID);
};

/**
 * Get detailed information for a specific bonus
 * @param {string} playerSessionID 
 * @param {string} bonusId Id of the bonus to retrieve, the bonus must be belong to the authenticated player
 */
export var getBonusById = function getBonusById(playerSessionID, bonusId) {
  return getProtected('/bonus/' + bonusId, playerSessionID);
};

/**
 * Get a list of all freespins (excluding pending) BonusAmount is the number of freespins awarded until they have been played at which point the value is the amount won on the freespins
 * @param {string} playerSessionID 
 */
export var getFreeSpins = function getFreeSpins(playerSessionID) {
  return getProtected('/bonus/freespins', playerSessionID);
};

/**
 * Get a list of all monetary bonuses (excluding pending)
 * @param {string} playerSessionID 
 */
export var getMonetaryBonuses = function getMonetaryBonuses(playerSessionID) {
  return getProtected('/bonus/monetary', playerSessionID);
};

/**
 * Get a list of all pending bonuses
 * @param {string} playerSessionID 
 */
export var getPendingBonuses = function getPendingBonuses(playerSessionID) {
  return getProtected('/bonus/pending', playerSessionID);
};

/**
 * Claim a pending bonus
 * @param {string} playerSessionID 
 * @param {string} bonusId Id of the bonus to claim, the bonus must be belong to the authenticated player
 */
export var claimBonus = function claimBonus(playerSessionID, bonusId) {
  return postProtected('/bonus/claim/' + bonusId, playerSessionID);
};

/**
 * Reject a pending bonus
 * @param {string} playerSessionID 
 * @param {string} bonusId Id of the bonus to claim, the bonus must be belong to the authenticated player
 */
export var rejectBonus = function rejectBonus(playerSessionID, bonusId) {
  return postProtected('/bonus/reject/' + bonusId, playerSessionID);
};

/**
 * Cancel a pending bonus
 * @param {string} playerSessionID 
 * @param {string} bonusId Id of the bonus to claim, the bonus must be belong to the authenticated player
 */
export var cancelBonus = function cancelBonus(playerSessionID, bonusId) {
  return postProtected('/bonus/cancel/' + bonusId, playerSessionID);
};

/**
 * Preclaim a bonus using promo code
 * @param {string} playerSessionID 
 * @param {string} promoCode
 */
export var preclaimBonus = function preclaimBonus(playerSessionID, promoCode) {
  return postProtected('/bonus/preclaim/' + promoCode, playerSessionID);
};

/**
 * Trigger a bonus manually using a promo code. The bonus has to be configured with the trigger type PromotionCode
 * @param {string} playerSessionID 
 * @param {string} promoCode
 */
export var triggerBonusByPromoCode = function triggerBonusByPromoCode(playerSessionID, promoCode) {
  return postProtected('/bonus/trigger/' + promoCode, playerSessionID);
};

/**
 * Get a list of all available offers for a specific trigger type. Note: Currently only type = deposit is supported
 * @param {string} playerSessionID 
 */
export var getOffers = function getOffers(playerSessionID) {
  return getProtected('/bonus/offers?type=Deposit', playerSessionID);
};

export default {
  getBonuses: getBonuses,
  getBonusById: getBonusById,
  getFreeSpins: getFreeSpins,
  getMonetaryBonuses: getMonetaryBonuses,
  getPendingBonuses: getPendingBonuses,
  claimBonus: claimBonus,
  rejectBonus: rejectBonus,
  cancelBonus: cancelBonus,
  preclaimBonus: preclaimBonus,
  triggerBonusByPromoCode: triggerBonusByPromoCode,
  getOffers: getOffers
};