import { get, post } from './utils';

export var getRecentDeposits = function getRecentDeposits(limit) {
  return get('/event-feed/recent-deposits?limit=' + limit);
};

export var getRecentGames = function getRecentGames() {
  var limit = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 10;
  return get('/event-feed/recent-games?limit=' + limit);
};

export var getRecentWins = function getRecentWins() {
  var limit = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 10;
  var threshold = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
  return get('/event-feed/recent-wins?limit=' + limit + '&threshold=' + threshold);
};

export var getRecentWinById = function getRecentWinById(gameId) {
  var limit = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10;
  var threshold = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 10;
  return get('/event-feed/recent-wins/' + gameId + '?limit=' + limit + '&threshold=' + threshold);
};

export var getRecentSignUps = function getRecentSignUps() {
  var limit = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 10;
  return get('/event-feed/recent-signups?limit=' + limit);
};

export var getRecentSignIns = function getRecentSignIns() {
  var limit = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 10;
  return get('/event-feed/recent-signins?limit=' + limit);
};

export var getJackpots = function getJackpots(currency) {
  return get('/event-feed/jackpots?currency=' + currency);
};

export var getTopGames = function getTopGames() {
  var limit = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 50;
  return get('/event-feed/top-games/' + limit);
};

export var getTopGamesWager = function getTopGamesWager() {
  var limit = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 50;
  return get('/event-feed/top-games-wager/' + limit);
};

export var getTopGamesUWC = function getTopGamesUWC() {
  var limit = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 50;
  return get('/event-feed/top-games-uwc/' + limit);
};

export var getLiveCasino = function getLiveCasino() {
  var gameIds = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  var tableIds = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;

  var query = '';

  if (gameIds) query += 'gameIds=' + gameIds;

  if (tableIds) query += gameIds ? '&tableIds=' + tableIds : 'tableIds=' + tableIds;

  return get('/event-feed/live-casino-lobby?' + query);
};

export var getLiveCasinoV2 = function getLiveCasinoV2(data) {
  return post('/event-feed/live-casino-lobby/v2', data);
};

export default {
  getRecentDeposits: getRecentDeposits,
  getRecentGames: getRecentGames,
  getRecentWins: getRecentWins,
  getRecentWinById: getRecentWinById,
  getRecentSignUps: getRecentSignUps,
  getRecentSignIns: getRecentSignIns,
  getJackpots: getJackpots,
  getTopGames: getTopGames,
  getTopGamesWager: getTopGamesWager,
  getTopGamesUWC: getTopGamesUWC,
  getLiveCasino: getLiveCasino,
  getLiveCasinoV2: getLiveCasinoV2
};