var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import { getFastTrackSid as getSid, getFastTrackToken as getToken } from './utils';
import axios from 'axios';

var ft2tg = function ft2tg(message) {
  return _extends({}, message, {
    Provider: 'fasttrack',
    Id: message.MessageId,
    Content: message.Message,
    Status: message.IsRead ? 'Read' : 'Unread',
    StartDate: message.Date,
    Attributes: _extends({}, message.Data, {
      ctaTranslationKey: message.CTAButtonText,
      ctaAction: message.CTAButtonLink
    })
  });
};

export var getMessages = function getMessages(a, b) {
  return getMessagesWithStatus(a, b);
};

export var getMessagesWithStatus = function getMessagesWithStatus(sessionId) {
  return new Promise(function (resolve, reject) {
    var g = window || global || {};

    getSid(sessionId).then(function (sid) {
      getToken(sid).then(function (authtoken) {
        axios({
          method: 'get',
          url: g.fastTrackAPIHost + '/Notifications/v2/user-notifications',
          headers: {
            authtoken: authtoken
          }
        }).then(function (res) {
          if (!res.data.Success) {
            console.error('Error', res);
            return reject();
          }

          return resolve({ data: res.data.Data.map(ft2tg) });
        });
      });
    });
  });
};

export var getMessage = function getMessage(sessionId) {
  return new Promise(function (resolve, reject) {
    var g = window || global || {};

    getSid(sessionId).then(function (sid) {
      getToken(sid).then(function (authtoken) {
        axios({
          method: 'get',
          url: g.fastTrackAPIHost + '/Notifications/v2/user-notification/' + messageID,
          headers: {
            authtoken: authtoken
          }
        }).then(function (res) {
          if (!res.data.Success) {
            console.error('Error', res);
            return reject();
          }

          return resolve(ft2tg(res.data.Data));
        });
      });
    });
  });
};

export var markMessage = function markMessage(sessionId, data) {
  return new Promise(function (resolve, reject) {
    var g = window || global || {};

    getSid(sessionId).then(function (sid) {
      getToken(sid).then(function (authtoken) {
        axios({
          method: 'post',
          url: g.fastTrackAPIHost + '/Notifications/MarkNotificationAsRead',
          data: data,
          headers: {
            authtoken: authtoken
          }
        }).then(function (res) {
          if (!res.data.Success) {
            console.error('Error', res);
            return reject(res);
          }

          return resolve(res);
        });
      });
    });
  });
};

export default {
  getMessages: getMessages,
  getMessagesWithStatus: getMessagesWithStatus,
  getMessage: getMessage,
  markMessage: markMessage
};