import { getProtected, postProtected, post, get } from './utils';

export var limitIncreaseInfo = function limitIncreaseInfo(playerSessionID) {
  return getProtected('/responsiblegaming/limit-increase-info', playerSessionID);
};

export var getLimit = function getLimit(playerSessionID) {
  return getProtected('/responsiblegaming/limit', playerSessionID);
};

export var setLimit = function setLimit(playerSessionID, data) {
  return postProtected('/responsiblegaming/limit', playerSessionID, data);
};

export var deleteLimit = function deleteLimit(playerSessionID, limitID, score) {
  score = typeof score !== 'undefined' ? '?pgsiScore=' + score : '';
  return postProtected('/responsiblegaming/limit/cancel/' + limitID + score, playerSessionID);
};

export var getRealityCheckSession = function getRealityCheckSession(playerSessionID) {
  return getProtected('/responsiblegaming/session', playerSessionID);
};

export var getRealityCheckData = function getRealityCheckData(playerSessionID) {
  return getProtected('/responsiblegaming/realitycheck-data', playerSessionID);
};

export var selfExclude = function selfExclude(playerSessionID, expiresIn) {
  return postProtected('/responsiblegaming/self-exclude/' + expiresIn, playerSessionID);
};

export var selfBlock = function selfBlock(playerSessionID, expiresIn) {
  return postProtected('/responsiblegaming/block/' + expiresIn, playerSessionID);
};

export var toConfirm = function toConfirm(playerSessionID) {
  return getProtected('/responsiblegaming/limit/to-confirm', playerSessionID);
};

export var confirm = function confirm(playerSessionID, id) {
  return postProtected('/responsiblegaming/limit/confirm/' + id, playerSessionID);
};

/**
 * declining waiting-for-confirmation of Game's Limitation
 * URL: /account/responsible-gaming
 * doc: http://api.preprod.aleacc.com/swagger/ui/index#!/ResponsibleGaming/ResponsibleGaming_DeclineLimit
 * @param playerSessionID
 * @param id
 * @returns {*}
 */
export var decline = function decline(playerSessionID, id) {
  return postProtected('/responsiblegaming/limit/decline/' + id, playerSessionID);
};

export var blockProduct = function blockProduct(playerSessionID, expiresIn, product) {
  return postProtected('/responsiblegaming/block-product/' + expiresIn, playerSessionID, product);
};

export var getProductBlocks = function getProductBlocks(playerSessionID) {
  return getProtected('/responsiblegaming/product-blocks', playerSessionID);
};

export var panic = function panic(playerSessionID, panicChoice) {
  return postProtected('/responsiblegaming/panic', playerSessionID, panicChoice);
};

export var pgsiScore = function pgsiScore(playerSessionID, Score) {
  return postProtected('/responsiblegaming/pgsi-score', playerSessionID, Score);
};

export var setLimitWithToken = function setLimitWithToken(limit) {
  return post('/responsiblegaming/limit/set-with-token', limit);
};

export var getLimitWithToken = function getLimitWithToken(token) {
  return get('/responsiblegaming/limit/get-with-token/?token=' + token);
};

export var getTableGamesSummary = function getTableGamesSummary(playerSessionID) {
  return getProtected('/responsiblegaming/table-games-summary', playerSessionID);
};

export var setMultipleLimits = function setMultipleLimits(playerSessionID, data) {
  return postProtected('/responsiblegaming/limit/multiple-limits', playerSessionID, data);
};

export default {
  getLimit: getLimit,
  getRealityCheckSession: getRealityCheckSession,
  getRealityCheckData: getRealityCheckData,
  setLimit: setLimit,
  deleteLimit: deleteLimit,
  pgsiScore: pgsiScore,
  selfBlock: selfBlock,
  selfExclude: selfExclude,
  toConfirm: toConfirm,
  confirm: confirm,
  decline: decline,
  blockProduct: blockProduct,
  getProductBlocks: getProductBlocks,
  panic: panic,
  limitIncreaseInfo: limitIncreaseInfo,
  setLimitWithToken: setLimitWithToken,
  getLimitWithToken: getLimitWithToken,
  getTableGamesSummary: getTableGamesSummary,
  setMultipleLimits: setMultipleLimits
};