var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import axios from 'axios';
import { createSSOToken } from './player';

function getHost() {
  if (typeof global !== 'undefined' && global.middlemanHost) return global.middlemanHost;
  if (typeof window !== 'undefined' && window.middlemanHost) return window.middlemanHost;
  return 'https://tg-middleman.herokuapp.com';
}

function NetworkException(data) {
  this.value = data;
  this.isNetworkException = true;
}

export var fetchJSON = function fetchJSON(url) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  return axios(_extends({
    url: '' + getHost() + url
  }, options)).catch(function (error) {
    try {
      var errorJson = JSON.parse(error);
      throw new NetworkException(errorJson);
    } catch (err) {
      throw new NetworkException(error);
    }
  });
};

export var post = function post(url, data) {
  return fetchJSON(url, {
    method: 'POST',
    data: data
  });
};

export var get = function get(url) {
  return fetchJSON(url);
};

export var postProtected = function postProtected(url, playerSessionID, data) {
  return fetchJSON(url, {
    method: 'POST',
    headers: {
      'X-Player-Session-Id': playerSessionID
    },
    data: data
  });
};

export var getProtected = function getProtected(url, playerSessionID) {
  return fetchJSON(url, {
    headers: {
      'X-Player-Session-Id': playerSessionID
    }
  });
};

export var uploadFile = function uploadFile(url, body, playerSessionID) {
  return axios({
    url: '' + getHost() + url,
    headers: {
      'X-Player-Session-Id': playerSessionID,
      'Content-Type': 'application/json'
    },
    method: 'POST',
    data: body
  });
};

export var getFastTrackSid = function getFastTrackSid(sessionId) {
  return new Promise(function (resolve, reject) {
    var g = window || global || {};
    if (!g._ftSid) {
      createSSOToken(sessionId, 'FastTrack').then(function (sid) {
        if (sid.status !== 200) {
          console.error('Error', sid);
          return reject();
        }

        g.sid = g._ftSid = sid.data;

        return resolve(g._ftSid);
      });
    } else {
      return resolve(g._ftSid);
    }
  });
};

export var getFastTrackToken = function getFastTrackToken(authtoken) {
  return new Promise(function (resolve, reject) {
    var g = window || global || {};
    if (!g._ftToken) {
      axios({
        method: 'post',
        url: g.fastTrackAPIHost + '/Platform/LoginAuthToken',
        headers: {
          authtoken: authtoken
        }
      }).then(function (tokenRes) {
        if (!tokenRes.data.Success) {
          console.error('Error', tokenRes);
          return reject();
        }

        g._ftToken = tokenRes.data.Data.Authentication.AuthToken;
        return resolve(g._ftToken);
      });
    } else {
      return resolve(g._ftToken);
    }
  });
};