'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getByCurrency = exports.setWallet = exports.getWallets = exports.getWallet = undefined;

var _utils = require('./utils');

/**
 * Gets a summary of the players current balance / reserved balance on his main currency wallet
 * @param {string} playerSessionID
 * @param {(null|'casino'|'bingo')} product Can be null, casino or bingo
 */
var getWallet = exports.getWallet = function getWallet(playerSessionID, product) {
  if (!product) {
    return (0, _utils.getProtected)('/wallet', playerSessionID);
  }

  return (0, _utils.getProtected)('/wallet?product=' + product, playerSessionID);
};

/**
 * Gets a summary of the players current balance / reserved balance per currency
 * @param {string} playerSessionID
 * @param {(null|'casino'|'bingo')} product Can be null, casino or bingo
 */
var getWallets = exports.getWallets = function getWallets(playerSessionID, product) {
  if (!product) {
    return (0, _utils.getProtected)('/wallets', playerSessionID);
  }

  return (0, _utils.getProtected)('/wallets?product=' + product, playerSessionID);
};

/**
 * Set's the players active currency, all transactions will be made against the wallets in this currency, if no wallet is currently setup for this currency then one will be created
 * @param {string} playerSessionID
 * @param {string} currency
 */
var setWallet = exports.setWallet = function setWallet(playerSessionID, currency) {
  return (0, _utils.postProtected)('/wallet?currency=' + currency, playerSessionID);
};

/**
 * Gets a summary of the players current balance / reserved balance for a specific currency.
 * @param {string} playerSessionID
 * @param {string} currency Currency to retrieve balance for
 * @param {(null|'casino'|'bingo')} [product] Can be null, casino or bingo
 */
var getByCurrency = exports.getByCurrency = function getByCurrency(playerSessionID, currency, product) {
  if (!product) {
    return (0, _utils.getProtected)('/wallet/' + currency, playerSessionID);
  }

  return (0, _utils.getProtected)('/wallet/' + currency + '?product=' + product, playerSessionID);
};

exports.default = {
  getWallet: getWallet,
  setWallet: setWallet,
  getWallets: getWallets,
  getByCurrency: getByCurrency
};